@@ -6,10 +6,11 @@ from typing import Any
 
 _CONNECTION_TIMEOUT = 5.0
 _READ_TIMEOUT = 5.0
+_READ_BUFFER = 512  # 512 bytes
 _QUEUE_WAIT_TIMEOUT = 1.0
-_DEFAULT_READ_BUFFER = 512  # 512 bytes
-_READ_WRITE_INTERVAL = 0.3
-_WRITE_RETRY_COUNT = 5
+_RECEIVE_INTERVAL = 0.3
+_SEND_INTERVAL = 0.4
+_SEND_RETRY_COUNT = 5
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -57,7 +58,8 @@ class WpSocketClient:
 
         self._connect_retry_cnt = 0
         self.connected = False
-        self._last_io_time = time.time()
+        self._last_receive_time = time.time()
+        self._last_send_time = time.time()
 
     async def async_on_connected(self):
         """Socket connected notifications"""
@@ -130,11 +132,11 @@ class WpSocketClient:
         _LOGGER.debug('reader start')
         while self.connected:
             try:
-                if (data := await asyncio.wait_for(self._reader.read(_DEFAULT_READ_BUFFER),
+                if (data := await asyncio.wait_for(self._reader.read(_READ_BUFFER),
                                                    timeout=_READ_TIMEOUT)) is None:
                     self._loop.create_task(self._async_reconnect())
                     break
-                self._last_io_time = time.time()
+                self._last_receive_time = time.time()
 
                 _LOGGER.debug('Received [%d]: %s', len(data), data.hex())
                 await self._receive_packet_queue.put(data)
@@ -152,24 +154,31 @@ class WpSocketClient:
                 send_data: _WpSendData = await asyncio.wait_for(self._send_packet_queue.get(),
                                                                 timeout=_QUEUE_WAIT_TIMEOUT)
                 while True:
-                    interval = time.time() - self._last_io_time
-                    if interval > _READ_WRITE_INTERVAL:
+                    now = time.time()
+                    send_interval = now - self._last_send_time
+                    receive_interval = now - self._last_receive_time
+                    if send_interval > _SEND_INTERVAL and receive_interval > _RECEIVE_INTERVAL:
                         self._writer.write(send_data.packet)
                         await self._writer.drain()
-                        self._last_io_time = time.time()
+                        self._last_send_time = time.time()
                         _LOGGER.debug('Send: %s', send_data.packet.hex())
                         send_data.set(True)
                         self._send_packet_queue.task_done()
                         break
 
-                    if send_data.inc_try() > _WRITE_RETRY_COUNT:
+                    if send_data.inc_try() > _SEND_RETRY_COUNT:
                         send_data.set(False)
                         _LOGGER.warning('Send fail: %s', send_data.packet.hex())
                         break
 
-                    delay = _READ_WRITE_INTERVAL - interval
-                    _LOGGER.info('Send wait: %f', delay)
-                    await asyncio.sleep(delay)
+                    if send_interval > receive_interval:
+                        delay = _SEND_INTERVAL - send_interval
+                        _LOGGER.info('Send, wait send interval: %f', delay)
+                        await asyncio.sleep(delay)
+                    else:
+                        delay = _RECEIVE_INTERVAL - receive_interval
+                        _LOGGER.info('Send, wait receive interval : %f', delay)
+                        await asyncio.sleep(delay)
 
             except asyncio.TimeoutError:
                 continue
